# Maintainers

See [Governance](governance.md) for what each maintainer type is

## Project maintainers

In alphabetical order

| Name           | GitHub Username  | Email                       | Organization       |
| -------------- | ---------------- |-----------------------------| ------------------ |
| Achal Shah     | `achals`         | achals@gmail.com            | Tecton             |
| Edson Tirelli   | `etirelli`       | ed.tirelli@gmail.com          | Red Hat          |
| Francisco Javier Arceo   | `franciscojavierarceo`       | arceofrancisco@gmail.com          | Affirm          |
| Hao Xu   | `HaoXuAI`       | sduxuhao@gmail.com          | JPMorgan          |
| Jeremy Ary   | `jeremyary`       | jeremy.ary@gmail.com          | Red Hat          |
| Shuchu Han  | `shuchu`       | shuchu.han@gmail.com          | Independent          |
| Willem Pienaar | `woop`           | will.pienaar@gmail.com      | Cleric             |
| Zhiling Chen   | `zhilingc`       | chnzhlng@gmail.com          | GetGround          |

## Emeritus Maintainers

| Name                | GitHub Username | Email                       | Organization      |
|---------------------|-----------------|-----------------------------|-------------------|
| Oleg Avdeev         | oavdeev         | oleg.v.avdeev@gmail.com     | Tecton            |
| Oleksii Moskalenko  | pyalex          | moskalenko.alexey@gmail.com | Tecton            |
| Jay Parthasarthy    | jparthasarthy   | jparthasarthy@gmail.com     | Tecton            |
| Danny Chiao         | adchia          | danny@tecton.ai             | Tecton            |
| Pradithya Aria Pura | pradithya       | pradithya.aria@gmail.com    | Gojek             |
| Tsotne Tabidze      | tsotnet         | tsotnet@gmail.com           | Tecton            |
| Abhin Chhabra       | chhabrakadabra  | chhabra.abhin@gmail.com     | Shopify           |
| Danny Chiao         | adchia          | danny@tecton.ai             | Tecton            |
| David Liu           | mavysavydav     | davidyliuliu@gmail.com      | Twitter           |
| Matt Delacour       | MattDelac       | mdelacour@hey.com           | Shopify           |
| Miles Adkins        | sfc-gh-madkins  | miles.adkins@snowflake.com | Snowflake        |
| Felix Wang     | `felixwang9817`  | wangfelix98@gmail.com       | Tecton             |
| Kevin Zhang    | `kevjumba`       | kevin.zhang.13499@gmail.com | Tecton             |
